summaryrefslogtreecommitdiffstats
path: root/kcachegrind/kcachegrind/callgraphview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kcachegrind/kcachegrind/callgraphview.cpp')
-rw-r--r--kcachegrind/kcachegrind/callgraphview.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kcachegrind/kcachegrind/callgraphview.cpp b/kcachegrind/kcachegrind/callgraphview.cpp
index c66c5809..99613171 100644
--- a/kcachegrind/kcachegrind/callgraphview.cpp
+++ b/kcachegrind/kcachegrind/callgraphview.cpp
@@ -369,7 +369,7 @@ TraceCall* GraphEdge::priorVisible()
// GraphOptions
//
-TQString GraphOptions::tqlayoutString(Layout l)
+TQString GraphOptions::layoutString(Layout l)
{
if (l == Circular) return TQString("Circular");
if (l == LeftRight) return TQString("LeftRight");
@@ -1313,8 +1313,8 @@ protected:
void CallGraphTip::maybeTip( const TQPoint& pos )
{
- if (!tqparentWidget()->inherits( "CallGraphView" )) return;
- CallGraphView* cgv = (CallGraphView*)tqparentWidget();
+ if (!parentWidget()->inherits( "CallGraphView" )) return;
+ CallGraphView* cgv = (CallGraphView*)parentWidget();
TQPoint cPos = cgv->viewportToContents(pos);
@@ -1367,9 +1367,9 @@ void CallGraphTip::maybeTip( const TQPoint& pos )
//
// CallGraphView
//
-CallGraphView::CallGraphView(TraceItemView* tqparentView,
+CallGraphView::CallGraphView(TraceItemView* parentView,
TQWidget* tqparent, const char* name)
- : TQCanvasView(tqparent, name), TraceItemView(tqparentView)
+ : TQCanvasView(tqparent, name), TraceItemView(parentView)
{
_zoomPosition = DEFAULT_ZOOMPOS;
_lastAutoPosition = TopLeft;
@@ -1786,7 +1786,7 @@ void CallGraphView::showRenderWarning()
TQString s;
if (_renderProcess)
- s =i18n("Warning: a long lasting graph tqlayouting is in progress.\n"
+ s =i18n("Warning: a long lasting graph layouting is in progress.\n"
"Reduce node/edge limits for speedup.\n");
else
s = i18n("Layouting stopped.\n");
@@ -1878,7 +1878,7 @@ void CallGraphView::refresh()
_unparsedOutput = TQString();
// tqlayouting of more than seconds is dubious
_renderTimer.start(1000, true);
}
@@ -2195,7 +2195,7 @@ void CallGraphView::dotExited()
if (!_canvas) {
_canvas = new TQCanvas(size().width(),size().height());
- TQString s = i18n("Error running the graph tqlayouting tool.\n");
+ TQString s = i18n("Error running the graph layouting tool.\n");
s += i18n("Please check that 'dot' is installed (package GraphViz).");
TQCanvasText* t = new TQCanvasText(s, _canvas);
t->move(5, 5);
@@ -2702,7 +2702,7 @@ void CallGraphView::readViewConfig(KConfig* c,
DEFAULT_CLUSTERGROUPS);
_detailLevel = g->readNumEntry("DetailLevel", DEFAULT_DETAILLEVEL);
_layout = GraphOptions::tqlayout(g->readEntry("Layout",
- tqlayoutString(DEFAULT_LAYOUT)));
+ layoutString(DEFAULT_LAYOUT)));
_zoomPosition = zoomPos(g->readEntry("ZoomPosition",
zoomPosString(DEFAULT_ZOOMPOS)));
@@ -2724,7 +2724,7 @@ void CallGraphView::saveViewConfig(KConfig* c,
DEFAULT_CLUSTERGROUPS);
writeConfigEntry(&g, "DetailLevel", _detailLevel, DEFAULT_DETAILLEVEL);
writeConfigEntry(&g, "Layout",
- tqlayoutString(_layout), tqlayoutString(DEFAULT_LAYOUT).utf8().data());
+ layoutString(_layout), layoutString(DEFAULT_LAYOUT).utf8().data());
writeConfigEntry(&g, "ZoomPosition",
zoomPosString(_zoomPosition),
zoomPosString(DEFAULT_ZOOMPOS).utf8().data());
@@ -1878,7 +1878,7 @@ void CallGraphView::refresh()
_unparsedOutput = TQString();
- // tqlayouting of more than seconds is dubious
+ // layouting of more than seconds is dubious
_renderTimer.start(1000, true);
}